import F from "futil";
import _ from "lodash/fp.js";
import React from "react";
import { setDisplayName } from "react-recompose";
import { Dynamic, Flex } from "./greyVest/index.js";
import { CheckButton, ModalPicker } from "./purgatory/index.js";
import { contexturifyWithoutLoader } from "./utils/hoc.js";
import { withTheme } from "./utils/theme.js";
import styles from "./styles/index.js";
import { newNodeFromField } from "./utils/search.js";
import { unusedOptions } from "./FilterAdder.js";
import { fieldsToOptions } from "./utils/fields.js";
let FilterButtonItem = _.flow(
  setDisplayName("FilterButtonItem"),
  withTheme
)(
  ({
    node,
    tree,
    fields,
    mapNodeToProps,
    mapNodeToLabel,
    theme: { Button, FilterButton = Button, UnmappedNodeComponent, Modal }
  }) => {
    let mappedProps = mapNodeToProps(node, fields);
    let modal = React.useState(false);
    let title = (
      // we really need a title, so here's every possible fallback
      mapNodeToLabel(node, fields) || _.get("label", mappedProps) || _.get([node.field, "label"], fields) || node.field || node.key
    );
    let description = _.get("description", mappedProps);
    return /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement(
      CheckButton,
      {
        primary: node.hasValue,
        checked: node.hasValue,
        onClick: () => {
          F.on(modal)();
          tree.mutate(node.path, { paused: false });
        },
        theme: { Button: FilterButton }
      },
      title
    ), /* @__PURE__ */ React.createElement(Modal, { open: modal }, /* @__PURE__ */ React.createElement(Flex, { column: true, className: "filter-button-modal" }, /* @__PURE__ */ React.createElement("h1", null, title), description && /* @__PURE__ */ React.createElement("div", { className: "filter-description" }, description), /* @__PURE__ */ React.createElement("div", { className: "filter-component" }, /* @__PURE__ */ React.createElement(
      Dynamic,
      {
        ...{
          component: UnmappedNodeComponent,
          tree,
          node,
          path: _.toArray(node.path),
          ...mappedProps
        }
      }
    )), /* @__PURE__ */ React.createElement(Flex, { style: { justifyContent: "flex-end" } }, /* @__PURE__ */ React.createElement(Button, { onClick: () => tree.clear(node.path) }, "Clear Filter"), /* @__PURE__ */ React.createElement(
      Button,
      {
        primary: true,
        onClick: () => {
          F.off(modal)();
          tree.mutate(node.path, { paused: true });
        },
        style: { marginLeft: "10px" }
      },
      "Done"
    )))));
  }
);
let GroupBox = ({ nodeJoinColor, children, nested, className, style }) => /* @__PURE__ */ React.createElement(
  Flex,
  {
    wrap: true,
    className: `${className} ${nested ? "nested" : ""}`,
    alignItems: "center",
    style: { borderColor: nodeJoinColor, ...style }
  },
  children
);
let FilterButtonList = contexturifyWithoutLoader(
  ({
    node,
    tree,
    fields = {},
    mapNodeToProps = _.noop,
    mapNodeToLabel = _.noop,
    allowDuplicateFields = false,
    className = "",
    addFilters = false,
    nested = false,
    style,
    children,
    theme: { Icon, Button, FilterButton = Button }
  }) => {
    let options = allowDuplicateFields ? fieldsToOptions(fields) : unusedOptions(fields);
    return /* @__PURE__ */ React.createElement(
      GroupBox,
      {
        className: `filter-button-list ${className}`,
        ...{ nested, style },
        nodeJoinColor: node && styles.joinColor(node)
      },
      children,
      _.map((child) => {
        let Component = child.children ? FilterButtonList : FilterButtonItem;
        return /* @__PURE__ */ React.createElement(
          Component,
          {
            key: child.path,
            nested: true,
            ...{
              tree,
              node: child,
              fields,
              mapNodeToProps,
              mapNodeToLabel,
              className
            }
          }
        );
      }, _.get("children", node)),
      addFilters && !nested && /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement(
        ModalPicker,
        {
          options,
          className: "check-button",
          onChange: (addedFields) => _.each(
            ({ field }) => tree.add(node.path, newNodeFromField({ field, fields })),
            addedFields
          ),
          label: /* @__PURE__ */ React.createElement(Flex, { alignItems: "center", justifyContent: "center" }, /* @__PURE__ */ React.createElement(Icon, { icon: "AddColumn" }), addFilters !== true && /* @__PURE__ */ React.createElement(React.Fragment, null, "\xA0", addFilters)),
          theme: { Button: FilterButton }
        }
      ))
    );
  }
);
var FilterButtonList_default = FilterButtonList;
export {
  FilterButtonList_default as default
};
