import React from "react";
import _ from "lodash/fp.js";
import F from "futil";
import { setDisplayName } from "react-recompose";
import { observer } from "mobx-react";
import { Expandable, Flex, Dynamic } from "./greyVest/index.js";
import { fieldsToOptions } from "./utils/fields.js";
import { contexturifyWithoutLoader } from "./utils/hoc.js";
import { bdJoin } from "./styles/generic.js";
import {
  newNodeFromType,
  transformNodeFromField,
  getTypeLabel,
  getTypeLabelOptions
} from "./utils/search.js";
import { withTheme } from "./utils/theme.js";
let FilterActions = _.flow(
  setDisplayName("FilterActions"),
  observer,
  withTheme
)(
  ({
    node,
    tree,
    fields,
    popover,
    theme: { DropdownItem, Popover, Modal, NestedPicker }
  }) => {
    let modal = React.useState(false);
    let typeOptions = _.flow(
      _.getOr([], [node.field, "typeOptions"]),
      _.without([node.type])
    )(fields);
    return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(Modal, { open: modal }, /* @__PURE__ */ React.createElement(
      NestedPicker,
      {
        options: fieldsToOptions(fields),
        onChange: (pickedFields) => {
          if (pickedFields.length > 0)
            tree.replace(
              node.path,
              transformNodeFromField({
                field: _.last(pickedFields).field,
                fields
              })
            );
          F.off(modal)();
        }
      }
    )), /* @__PURE__ */ React.createElement(
      Popover,
      {
        open: popover,
        arrow: false,
        position: "bottom center",
        style: { width: "auto" }
      },
      !_.isEmpty(typeOptions) && /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(DropdownItem, { className: "filter-actions-selected-type" }, "Filter type: ", /* @__PURE__ */ React.createElement("strong", null, getTypeLabel(tree, node.type))), _.map(
        (x) => /* @__PURE__ */ React.createElement(
          DropdownItem,
          {
            key: x.value,
            onClick: () => tree.replace(
              node.path,
              newNodeFromType(x.value, fields, node)
            )
          },
          "\u2014Change to ",
          x.label
        ),
        getTypeLabelOptions(tree, typeOptions)
      ), /* @__PURE__ */ React.createElement("div", { className: "filter-actions-separator" })),
      /* @__PURE__ */ React.createElement(DropdownItem, { onClick: F.on(modal) }, "Pick Field"),
      (node.hasValue || false) && /* @__PURE__ */ React.createElement(DropdownItem, { onClick: () => tree.clear(node.path) }, "Clear Filter"),
      /* @__PURE__ */ React.createElement(DropdownItem, { onClick: () => tree.remove(node.path) }, "Delete Filter")
    ));
  }
);
let Label = _.flow(
  setDisplayName("Label"),
  observer,
  withTheme
)(({ tree, node, fields, children, theme: { Icon }, ...props }) => {
  let popover = React.useState(false);
  let modal = React.useState(false);
  let field = _.get("field", node);
  return /* @__PURE__ */ React.createElement(
    Flex,
    {
      className: `filter-field-label ${_.get("hasValue", node) ? "filter-field-has-value" : ""}`.trim(),
      style: {
        cursor: "pointer",
        alignItems: "center",
        justifyContent: "space-between"
      }
    },
    /* @__PURE__ */ React.createElement("span", { ...props }, children || _.get([field, "label"], fields) || field || ""),
    tree && node && /* @__PURE__ */ React.createElement(
      React.Fragment,
      null,
      /* @__PURE__ */ React.createElement(
        "span",
        {
          onClick: node.paused ? null : (e) => {
            e.stopPropagation();
            F.flip(popover)();
          }
        },
        /* @__PURE__ */ React.createElement("span", { className: "filter-field-label-icon" }, /* @__PURE__ */ React.createElement(Icon, { icon: "TableColumnMenu" })),
        /* @__PURE__ */ React.createElement(
          FilterActions,
          {
            node,
            tree,
            fields,
            popover,
            modal
          }
        )
      ),
      // Whitespace separator
      /* @__PURE__ */ React.createElement("div", { style: { flexGrow: 1 } })
    )
  );
});
let FilterList = _.flow(
  setDisplayName("FilterList"),
  contexturifyWithoutLoader
)(
  ({
    tree,
    node,
    fields,
    mapNodeToProps = _.noop,
    mapNodeToLabel = _.noop,
    className,
    style,
    theme: { UnmappedNodeComponent, Button }
  }) => {
    let updateRequired = tree.disableAutoUpdate && tree?.tree?.markedForUpdate;
    return /* @__PURE__ */ React.createElement("div", { style, className }, _.map(
      (child) => child.children ? /* @__PURE__ */ React.createElement(
        FilterList,
        {
          key: child.path,
          tree,
          node: child,
          fields,
          mapNodeToProps,
          mapNodeToLabel,
          className: "filter-list-group",
          style: bdJoin(child)
        }
      ) : /* @__PURE__ */ React.createElement(
        Expandable,
        {
          key: child.path,
          className: "filter-list-item",
          isOpen: !child.paused,
          Label: /* @__PURE__ */ React.createElement(Label, { tree, node: child, fields }, mapNodeToLabel(child, fields)),
          onClick: () => tree && tree.mutate(child.path, { paused: !child.paused })
        },
        /* @__PURE__ */ React.createElement("div", { className: "filter-list-item-contents" }, /* @__PURE__ */ React.createElement(
          Dynamic,
          {
            ...{
              component: UnmappedNodeComponent,
              tree,
              node: child,
              path: _.toArray(child.path),
              ...mapNodeToProps(child, fields)
            }
          }
        ))
      ),
      _.get("children", node)
    ), /* @__PURE__ */ React.createElement(
      "div",
      {
        className: `apply-filter ${updateRequired ? "active" : ""}`,
        onClick: (e) => {
          e.stopPropagation();
          tree.triggerUpdate();
        }
      },
      /* @__PURE__ */ React.createElement(Button, { primary: true }, /* @__PURE__ */ React.createElement(Flex, { justifyContent: "center", alignItems: "center" }, "Search"))
    ));
  }
);
var FilterList_default = FilterList;
export {
  FilterActions,
  Label,
  FilterList_default as default
};
