import React from "react";
import _ from "lodash/fp.js";
import PropTypes from "prop-types";
import F from "futil";
import { observer } from "mobx-react";
import FilterList from "./FilterList.js";
import FilterAdder from "./FilterAdder.js";
import QueryBuilder from "./queryBuilder/index.js";
import { TreePauseButton } from "./purgatory/index.js";
import { Flex, LinkButton, Popover, DropdownItem } from "./greyVest/index.js";
import { withTheme } from "./utils/theme.js";
let SearchTree = () => {
};
let LabelledList = ({ list, Component }) => F.mapIndexed(
  ({ label, ...props }, i) => /* @__PURE__ */ React.createElement(React.Fragment, { key: i }, label && /* @__PURE__ */ React.createElement("h3", null, label), /* @__PURE__ */ React.createElement(Component, { ...props })),
  list
);
let AddableFilterList = (props) => /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(FilterList, { ...props }), /* @__PURE__ */ React.createElement(FilterAdder, { ...props, uniqueFields: !props.allowDuplicateFields }));
let FiltersBox = withTheme(({ theme: { Box }, ...props }) => /* @__PURE__ */ React.createElement(Box, { className: "filter-list" }, /* @__PURE__ */ React.createElement(AddableFilterList, { ...props })));
FiltersBox.displayName = "FiltersBox";
let BasicSearchFilters = withTheme(
  ({
    setMode,
    disableAdvancedMode,
    trees,
    children,
    BasicFilters,
    theme: { Icon }
  }) => /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement(Flex, { alignItems: "center", justifyContent: "space-between" }, /* @__PURE__ */ React.createElement("h1", null, "Filters"), /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement(
    Popover,
    {
      position: "bottom right",
      trigger: /* @__PURE__ */ React.createElement(DropdownItem, null, /* @__PURE__ */ React.createElement(Icon, { icon: "TableColumnMenu" }))
    },
    setMode && /* @__PURE__ */ React.createElement(DropdownItem, { onClick: () => setMode("resultsOnly") }, "Hide Filters"),
    /* @__PURE__ */ React.createElement(TreePauseButton, { Component: DropdownItem }, children),
    setMode && !disableAdvancedMode && /* @__PURE__ */ React.createElement(DropdownItem, { onClick: () => setMode("builder") }, "Advanced Search Builder")
  ))), /* @__PURE__ */ React.createElement(LabelledList, { list: trees, Component: BasicFilters }))
);
let BuilderSearchFilters = ({ setMode, trees, BuilderFilters }) => /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement(Flex, { alignItems: "center", justifyContent: "space-between" }, /* @__PURE__ */ React.createElement("h1", null, "Filters"), setMode && /* @__PURE__ */ React.createElement(LinkButton, { onClick: () => setMode("basic") }, "Back to Regular Search")), /* @__PURE__ */ React.createElement(LabelledList, { list: trees, Component: BuilderFilters }));
let SearchFilters = ({
  mode,
  setMode,
  disableAdvancedMode,
  children,
  // pass allowDuplicateFields in children to override uniqueFields
  BasicFilters = FiltersBox,
  BuilderFilters = QueryBuilder
}) => {
  let trees = _.flow(React.Children.toArray, _.map("props"))(children);
  return mode === "basic" ? /* @__PURE__ */ React.createElement(
    BasicSearchFilters,
    {
      ...{ trees, setMode, disableAdvancedMode, children, BasicFilters }
    }
  ) : mode === "builder" ? /* @__PURE__ */ React.createElement(BuilderSearchFilters, { ...{ trees, setMode, BuilderFilters } }) : null;
};
SearchFilters.propTypes = {
  mode: PropTypes.oneOf(["basic", "builder", "resultsOnly"])
};
var SearchFilters_default = observer(SearchFilters);
export {
  AddableFilterList,
  FiltersBox,
  SearchTree,
  SearchFilters_default as default
};
