import React from "react";
import _ from "lodash/fp.js";
import F from "futil";
import { setDisplayName } from "react-recompose";
import { observer } from "mobx-react";
import { getResults, getRecord } from "../utils/schema.js";
import { contexturifyWithoutLoader } from "../utils/hoc.js";
import { withTheme } from "../utils/theme.js";
import ResultTable from "./ResultTable/index.js";
import { selectedBinding } from "./utils.js";
import { expandProp } from "../utils/react.js";
let Label = _.flow(
  setDisplayName("Label"),
  observer,
  withTheme
)(({ node, selected, getValue, theme }) => {
  let results = _.toArray(getResults(node));
  let allChecked = _.size(results) === _.size(F.view(selected));
  let checkAll = F.sets(
    allChecked ? [] : _.map(_.flow(getRecord, _.iteratee(getValue)), results),
    selected
  );
  return /* @__PURE__ */ React.createElement(theme.Checkbox, { checked: allChecked, onChange: checkAll });
});
let CheckableResultTable = ({
  node,
  fields,
  selectedValues,
  onChange,
  getValue,
  theme,
  ...props
}) => /* @__PURE__ */ React.createElement(
  ResultTable,
  {
    fields: {
      _checkbox: _.merge(
        {
          hideMenu: true,
          label: () => /* @__PURE__ */ React.createElement(
            Label,
            {
              ...{
                node,
                selected: [selectedValues, onChange],
                getValue,
                theme
              }
            }
          ),
          display: (x, y) => {
            let value = _.iteratee(getValue)(y);
            return !_.isNil(value) && /* @__PURE__ */ React.createElement(
              theme.Checkbox,
              {
                ...F.domLens.checkboxValues(value, [
                  selectedValues,
                  onChange
                ])
              }
            );
          }
        },
        fields._checkbox
      ),
      ..._.omit("_checkbox", fields)
    },
    ...props
  }
);
var CheckableResultTable_default = _.flow(
  expandProp("selected", selectedBinding),
  contexturifyWithoutLoader
)(CheckableResultTable);
export {
  CheckableResultTable_default as default
};
