import React from "react";
import _ from "lodash/fp.js";
import F from "futil";
import { observer } from "mobx-react";
import { toNumber } from "../../utils/format.js";
import { convertWordToTag } from "../TagsQuery/utils.js";
let keysToLower = _.flow(_.keys, _.map(_.toLower));
let addIcon = /* @__PURE__ */ React.createElement(
  "i",
  {
    className: "material-icons",
    style: { padding: "0px 2px", fontSize: "small" }
  },
  "add"
);
let BlankRemoveIcon = () => /* @__PURE__ */ React.createElement("div", { style: { padding: 3 } });
let tipStrings = [
  "Click the keyword generator icon again to regenerate new suggestions based on the keywords selected for your search.",
  "Click on a keyword to add it to your search.",
  "Enter a minimum of 3 keywords to start generating suggestions.",
  "Enter more than 3 keywords to improve the quality of the suggestions"
];
let KeywordGenerations = ({
  node,
  tree,
  Tag,
  generationsCollapsed,
  innerEdgeMargins = {},
  Loader
}) => {
  let [tips, setTips] = React.useState([...tipStrings]);
  React.useEffect(() => {
    F.when(
      setTips((tips2) => [_.last(tips2), ..._.dropRight(1, tips2)]),
      F.view(generationsCollapsed)
    );
  }, [generationsCollapsed]);
  return /* @__PURE__ */ React.createElement("div", { style: !F.view(generationsCollapsed) ? {} : { display: "none" } }, /* @__PURE__ */ React.createElement("div", null, node.isStale && node.generateKeywords && _.size(node.tags) <= 100 && /* @__PURE__ */ React.createElement(Loader, { style: { textAlign: "center" }, loading: true }, "Loading..."), !node.generateKeywords && _.map((word) => /* @__PURE__ */ React.createElement(
    Tag,
    {
      tree,
      node,
      onClick: ({ value, label }) => tree.mutate(node.path, {
        tags: [...node.tags, convertWordToTag(value, label)]
      }),
      AddIcon: addIcon,
      key: `tag-${word}`,
      RemoveIcon: BlankRemoveIcon,
      hoverColor: "#A9A9A9",
      tagStyle: {
        borderRadius: "3px",
        padding: "0px 0px",
        backgroundColor: "#E2E2E2"
      },
      value: `${word}`,
      label: `${word} (${toNumber(
        _.get(`context.keywordGenerations.${word}`)(node)
      )})`
    }
  ))(
    _.reject(
      _.includes(_, _.map("word", node.tags)),
      keysToLower(node.context?.keywordGenerations)
    )
  ), _.size(node.tags) > 100 && _.size(node.context?.keywordGenerations) === 0 && "Keyword suggestions are limited once 100 or more keywords are present, please remove some keywords to generate suggestions."), /* @__PURE__ */ React.createElement(
    "div",
    {
      style: {
        ...!_.isEmpty(innerEdgeMargins) && {
          marginRight: innerEdgeMargins.marginRight,
          marginLeft: innerEdgeMargins.marginLeft,
          marginBottom: innerEdgeMargins.marginBottom
        },
        backgroundColor: "#f5f5f5",
        marginTop: "12px",
        padding: "4px 12px",
        borderBottomRightRadius: 3,
        borderBottomLeftRadius: 3,
        display: "grid",
        gridTemplateColumns: "18px 15px fit-content(100%) 15px"
      }
    },
    /* @__PURE__ */ React.createElement(
      "i",
      {
        className: "material-icons",
        style: {
          margin: "auto 0",
          padding: "0px 2px",
          paddingTop: "1px",
          opacity: "0.5",
          fontSize: "small"
        }
      },
      "info"
    ),
    /* @__PURE__ */ React.createElement(
      "span",
      {
        onClick: () => setTips((tips2) => [..._.tail(tips2), _.head(tips2)])
      },
      /* @__PURE__ */ React.createElement(
        "i",
        {
          className: "material-icons",
          style: {
            margin: "auto 0",
            padding: "0px 2px",
            paddingTop: "1px",
            opacity: "0.5",
            fontSize: "small",
            cursor: "pointer"
          }
        },
        "chevron_left"
      )
    ),
    /* @__PURE__ */ React.createElement(
      "span",
      {
        style: {
          fontFamily: "Lato",
          fontSize: "12px",
          fontWeight: "normal",
          fontStretch: "normal",
          fontStyle: "italic",
          margin: "auto 0"
        }
      },
      "Tip: ",
      tips[0]
    ),
    /* @__PURE__ */ React.createElement(
      "span",
      {
        onClick: () => setTips((tips2) => [_.last(tips2), ..._.dropRight(1, tips2)])
      },
      /* @__PURE__ */ React.createElement(
        "i",
        {
          className: "material-icons",
          style: {
            margin: "auto 0",
            padding: "0px 2px",
            paddingTop: "1px",
            opacity: "0.5",
            fontSize: "small",
            cursor: "pointer"
          }
        },
        "chevron_right"
      )
    )
  ));
};
var KeywordGenerations_default = observer(KeywordGenerations);
export {
  KeywordGenerations_default as default
};
