import React from "react";
import _ from "lodash/fp.js";
import F from "futil";
import { withContentRect } from "react-measure";
import { toJS } from "mobx";
import { contexturifyWithoutLoader } from "../../utils/hoc.js";
import ExpandArrow from "./ExpandArrow.js";
import { observer } from "mobx-react";
import { toNumber } from "../../utils/format.js";
import TagActionsMenu from "../TagsQuery/TagActionsMenu.js";
import { Grid, GridItem, TextButton } from "../../greyVest/index.js";
import {
  getTagStyle,
  tagValueField,
  convertWordToTag
} from "../TagsQuery/utils.js";
import ActionsMenu from "../TagsQuery/ActionsMenu.js";
import { useOutsideClick } from "@chakra-ui/react-use-outside-click";
import { sanitizeTagInputs } from "contexture-util/keywordGenerations.js";
import KeywordGenerations from "./KeywordGenerations.js";
import { sanitizeQueryStringTag } from "../../greyVest/utils.js";
let innerHeightLimit = 40;
let isKeywordLightBulbOn = (tags) => sanitizeTagInputs(tags)?.length > 2;
let triggerKeywordGeneration = async (node, tree) => {
  await tree.mutate(node.path, { generateKeywords: true });
  tree.mutate(node.path, { generateKeywords: false });
};
let KeywordGenerationIcon = ({ strokeColor = "currentColor" }) => /* @__PURE__ */ React.createElement(
  "svg",
  {
    xmlns: "http://www.w3.org/2000/svg",
    className: "h-6 w-6",
    viewBox: "0 0 24 24",
    fill: "none",
    stroke: strokeColor,
    strokeWidth: "2"
  },
  /* @__PURE__ */ React.createElement("title", null, "Enter 3 keywords to generate keyword suggestions."),
  /* @__PURE__ */ React.createElement(
    "path",
    {
      strokeLinecap: "round",
      strokeLinejoin: "round",
      d: "M9.663 17h4.673M12 3v1m6.364 1.636l-.707.707M21 12h-1M4 12H3m3.343-5.657l-.707-.707m2.828 9.9a5 5 0 117.072 0l-.548.547A3.374 3.374 0 0014 18.469V19a2 2 0 11-4 0v-.531c0-.895-.356-1.754-.988-2.386l-.548-.547z"
    }
  )
);
let ExpandableTagsQuery = ({
  measureRef,
  contentRect,
  collapse,
  hasPopover,
  theme,
  tree,
  node,
  innerEdgeMargins = {},
  ...props
}) => {
  let generationsCollapsed = React.useState(true);
  let { marginRight, marginLeft } = innerEdgeMargins;
  let ref = React.useRef();
  useOutsideClick({
    ref,
    handler: () => !hasPopover?.current && F.on(generationsCollapsed)()
  });
  let showMoreKeywordsButton = F.view(collapse) && contentRect.entry.height > innerHeightLimit && !!node.tags.length;
  return /* @__PURE__ */ React.createElement("div", { ref, onMouseUp: (e) => e.stopPropagation() }, /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement(
    "div",
    {
      style: {
        overflow: "hidden",
        maxHeight: F.view(collapse) ? innerHeightLimit : ""
      }
    },
    /* @__PURE__ */ React.createElement("div", { ref: measureRef }, /* @__PURE__ */ React.createElement(
      TagsWrapper,
      {
        ..._.omit("measure", props),
        tree,
        node,
        theme,
        hasPopover,
        generationsCollapsed
      }
    ))
  ), showMoreKeywordsButton && /* @__PURE__ */ React.createElement("div", { style: { minHeight: 10 } }, /* @__PURE__ */ React.createElement(ExpandArrow, { collapse, tagsLength: node.tags.length }))), !F.view(generationsCollapsed) && /* @__PURE__ */ React.createElement(
    "hr",
    {
      style: {
        border: "1px solid #EBEBEB",
        ...!_.isEmpty(innerEdgeMargins) && { marginLeft, marginRight },
        ...!F.view(collapse) && { marginBottom: "10px" },
        ...showMoreKeywordsButton && { marginBottom: 20 }
      }
    }
  ), /* @__PURE__ */ React.createElement(
    KeywordGenerations,
    {
      node,
      tree,
      Tag: theme.Tag,
      generationsCollapsed,
      innerEdgeMargins,
      ...props
    }
  ));
};
let TagsWrapper = observer(
  ({
    tree,
    node,
    style,
    actionWrapper,
    onAddTag = _.noop,
    onTagsDropped = _.noop,
    popoverPosition = "bottom right",
    popoverArrow,
    popoverOffsetY,
    theme: { Icon, TagsInput, Tag, Popover },
    joinOptions,
    splitCommas = true,
    maxTags = 1e3,
    hasPopover,
    enableKeywordGenerations,
    generationsCollapsed,
    ...props
  }) => {
    let TagWithPopover = React.memo(
      observer((props2) => {
        let count = _.get(["context", "tags", props2.value], node) ?? _.get(["context", "keywordGenerations", props2.value], node) ?? (node.forceFilterOnly || node.updating ? void 0 : F.when(
          _.isNaN(),
          void 0,
          _.get(`context.tags.${props2.value}`, node)
        ));
        let tagProps = {
          ...props2,
          ...!_.isNil(count) && {
            label: `${props2.value} (${toNumber(count)})`
          }
        };
        return /* @__PURE__ */ React.createElement(
          Popover,
          {
            position: "right top",
            closeOnPopoverClick: false,
            trigger: /* @__PURE__ */ React.createElement(Tag, { ...tagProps }),
            onOpen: () => hasPopover.current = true,
            onClose: () => hasPopover.current = false
          },
          /* @__PURE__ */ React.createElement(
            TagActionsMenu,
            {
              tag: props2.value,
              ...{ node, tree },
              onChange: () => hasPopover.current = false
            }
          )
        );
      })
    );
    return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(
      Grid,
      {
        "data-path": node.path,
        rows: `${innerHeightLimit}px minmax(0, auto)`,
        columns: "1fr auto auto",
        style: { ...style, marginBottom: 10 }
      },
      /* @__PURE__ */ React.createElement(GridItem, { height: 2, place: "center stretch" }, /* @__PURE__ */ React.createElement(
        TagsInput,
        {
          splitCommas,
          sanitizeTagFn: sanitizeQueryStringTag,
          maxTags,
          tags: node.tags?.length > 0 ? _.map(tagValueField, node.tags) : F.on(generationsCollapsed)(),
          onTagsDropped,
          addTags: (addedTags) => {
            let addedTagObjects = _.map(convertWordToTag, addedTags);
            let tags = [...node.tags, ...addedTagObjects];
            if (_.size(tags) > maxTags) {
              tags = _.take(maxTags, tags);
              onTagsDropped(maxTags, tags);
            }
            tree.mutate(node.path, { tags });
            onAddTag(tags);
          },
          removeTag: (tag) => {
            tree.mutate(node.path, {
              tags: _.reject({ [tagValueField]: tag }, node.tags)
            });
            node.tags?.length <= 2 && F.on(generationsCollapsed)();
          },
          tagStyle: getTagStyle(node, tagValueField),
          submit: tree.triggerUpdate,
          Tag: TagWithPopover,
          style: { flex: 1, border: 0 },
          ...props
        }
      )),
      /* @__PURE__ */ React.createElement(GridItem, { place: "center" }, /* @__PURE__ */ React.createElement(
        TextButton,
        {
          style: (
            // Show suggestion lightbulb if min of 3 non numeric tags exist,
            // including numbers ups the chance of producing bad suggestions
            {
              display: "flex",
              width: 32,
              strokeOpacity: 0.5,
              ...!enableKeywordGenerations && { display: "none" },
              ...isKeywordLightBulbOn(node.tags) && {
                strokeOpacity: 1
              }
            }
          ),
          onClick: async () => {
            if (!node.generateKeywords && isKeywordLightBulbOn(node.tags)) {
              let collapsedState = F.view(generationsCollapsed);
              let context = toJS(node.context);
              F.off(generationsCollapsed)();
              if (!collapsedState || _.isEmpty(context.keywordGenerations) || _.isEmpty(
                _.difference(
                  _.keys(context.keywordGenerations),
                  _.keys(context.tags)
                )
              )) {
                await triggerKeywordGeneration(node, tree);
              }
            }
          }
        },
        /* @__PURE__ */ React.createElement(
          KeywordGenerationIcon,
          {
            strokeColor: isKeywordLightBulbOn(node.tags) ? "#0076de" : "currentColor"
          }
        )
      )),
      /* @__PURE__ */ React.createElement(GridItem, { place: "center" }, /* @__PURE__ */ React.createElement(
        Popover,
        {
          style: { width: "auto" },
          position: popoverPosition,
          arrow: popoverArrow,
          offsetY: popoverOffsetY,
          closeOnPopoverClick: false,
          trigger: /* @__PURE__ */ React.createElement("div", { style: { display: "flex", justifyContent: "center" } }, /* @__PURE__ */ React.createElement(Icon, { icon: "TableColumnMenu" }))
        },
        (close) => /* @__PURE__ */ React.createElement(
          ActionsMenu,
          {
            ...{
              node,
              tree,
              close,
              actionWrapper,
              joinOptions
            }
          }
        )
      ))
    ));
  }
);
var ExpandableTagsQuery_default = _.flow(
  contexturifyWithoutLoader,
  withContentRect()
)(ExpandableTagsQuery);
export {
  ExpandableTagsQuery_default as default
};
