import React from "react";
import _ from "lodash/fp.js";
import F from "futil";
import { observer } from "mobx-react";
import { Dynamic, Flex } from "../../greyVest/index.js";
import { withTheme } from "../../utils/theme.js";
const moveColumn = (mutate, computeNextIndex, field, visibleFields, includes) => {
  let visibleFieldIndex = _.findIndex({ field }, visibleFields);
  let nextField = _.flow(
    _.nth(computeNextIndex(visibleFieldIndex)),
    _.get("field")
  )(visibleFields);
  mutate({
    include: F.moveIndex(
      _.indexOf(field, includes),
      _.indexOf(nextField, includes),
      includes
    )
  });
};
let popoverStyle = {
  userSelect: "none",
  width: "auto"
};
let DefaultHeaderCell = withTheme(({ children, theme: { Th }, ...props }) => /* @__PURE__ */ React.createElement(Th, { ...props }, /* @__PURE__ */ React.createElement(Flex, { style: { display: "inline-flex", alignItems: "center" } }, children)));
let Header = ({
  field: fieldSchema,
  includes,
  addOptions,
  addFilter,
  tree,
  node,
  mutate,
  criteria,
  mapNodeToProps,
  fields,
  visibleFields,
  isStickyColumn,
  isLastColumn,
  theme: {
    Button,
    DropdownItem,
    Icon,
    Popover,
    Modal,
    NestedPicker,
    UnmappedNodeComponent
  }
}) => {
  let adding = React.useState(false);
  let {
    disableFilter,
    disableSort,
    field,
    sortField = field,
    label,
    hideRemoveColumn,
    hideMenu,
    typeDefault
  } = fieldSchema;
  let HeaderCell = fieldSchema.HeaderCell || DefaultHeaderCell;
  let filterNode = criteria && _.find({ field }, _.getOr([], "children", tree.getNode(criteria)));
  let filtering = React.useState(!!filterNode && !_.get("paused", filterNode));
  let filter = () => {
    if (!filterNode)
      addFilter(field);
    filterNode = criteria && _.find({ field }, _.getOr([], "children", tree.getNode(criteria)));
    tree.mutate(filterNode.path, { paused: false });
    F.flip(filtering)();
  };
  let Label = label;
  let { className, style, ...headerCellProps } = fieldSchema.headerCellProps ?? {};
  return /* @__PURE__ */ React.createElement(
    HeaderCell,
    {
      className: `${isStickyColumn ? "sticky-column-header" : ""}
        ${_.get("hasValue", filterNode) ? "active-filter" : ""} ${className}`,
      style: {
        cursor: hideMenu ? "default" : "pointer",
        left: isStickyColumn ? 0 : "",
        ...style
      },
      ...headerCellProps
    },
    _.isFunction(label) ? /* @__PURE__ */ React.createElement(Label, null) : label,
    " ",
    field === node.sortField && /* @__PURE__ */ React.createElement(
      Icon,
      {
        icon: node.sortDir === "asc" ? "SortAscending" : "SortDescending"
      }
    ),
    /* @__PURE__ */ React.createElement(
      Popover,
      {
        trigger: hideMenu ? null : /* @__PURE__ */ React.createElement(Icon, { icon: "TableColumnMenu" }),
        position: `bottom ${isLastColumn ? "right" : "center"}`,
        closeOnPopoverClick: false,
        style: popoverStyle
      },
      !disableSort && /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(DropdownItem, { onClick: () => mutate({ sortField, sortDir: "asc" }) }, /* @__PURE__ */ React.createElement(Icon, { icon: "SortAscending" }), "Sort Ascending"), /* @__PURE__ */ React.createElement(
        DropdownItem,
        {
          onClick: () => mutate({ sortField, sortDir: "desc" })
        },
        /* @__PURE__ */ React.createElement(Icon, { icon: "SortDescending" }),
        "Sort Descending"
      )),
      /* @__PURE__ */ React.createElement(
        DropdownItem,
        {
          onClick: () => moveColumn(mutate, (i) => i - 1, field, visibleFields, includes)
        },
        /* @__PURE__ */ React.createElement(Icon, { icon: "MoveLeft" }),
        "Move Left"
      ),
      /* @__PURE__ */ React.createElement(
        DropdownItem,
        {
          onClick: () => moveColumn(mutate, (i) => i + 1, field, visibleFields, includes)
        },
        /* @__PURE__ */ React.createElement(Icon, { icon: "MoveRight" }),
        "Move Right"
      ),
      !hideRemoveColumn && /* @__PURE__ */ React.createElement(
        DropdownItem,
        {
          onClick: () => mutate({ include: _.without([field], includes) })
        },
        /* @__PURE__ */ React.createElement(Icon, { icon: "RemoveColumn" }),
        "Remove Column"
      ),
      !!addOptions.length && /* @__PURE__ */ React.createElement(DropdownItem, { onClick: F.on(adding) }, /* @__PURE__ */ React.createElement(Icon, { icon: "AddColumn" }), "Add Column"),
      criteria && (typeDefault || filterNode) && !disableFilter && /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement(DropdownItem, { onClick: filter }, /* @__PURE__ */ React.createElement(
        Icon,
        {
          icon: filterNode ? F.view(filtering) ? "FilterCollapse" : "FilterExpand" : "FilterAdd"
        }
      ), "Filter"), F.view(filtering) && filterNode && !filterNode.paused && /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(
        Dynamic,
        {
          ...{
            component: UnmappedNodeComponent,
            tree,
            path: _.toArray(filterNode.path),
            ...mapNodeToProps(filterNode, fields)
          }
        }
      ), tree.disableAutoUpdate && node.markedForUpdate && /* @__PURE__ */ React.createElement(
        Button,
        {
          primary: true,
          style: { width: "100%" },
          onClick: (e) => {
            e.stopPropagation();
            tree.triggerUpdate();
          }
        },
        "Search"
      ))),
      /* @__PURE__ */ React.createElement(Modal, { open: adding }, /* @__PURE__ */ React.createElement(
        NestedPicker,
        {
          itemType: "column",
          options: addOptions,
          onChange: (selectedFields) => {
            _.each(({ field: addedField }) => {
              let index = includes.indexOf(field);
              if (index >= 0 && addedField) {
                includes.splice(index + 1, 0, addedField);
                mutate({ include: includes });
              }
            }, selectedFields);
            F.off(adding)();
          }
        }
      ))
    )
  );
};
var Header_default = _.flow(observer, withTheme)(Header);
export {
  Header_default as default
};
