import React from "react";
import _ from "lodash/fp.js";
import { observer } from "mobx-react";
import { getRecord, getResults } from "../../utils/schema.js";
import { addBlankRows, blankResult } from "../../utils/format.js";
import { withTheme } from "../../utils/theme.js";
import { StripedLoader } from "../../greyVest/index.js";
let displayCell = ({ display, value, record, result, ...props }) => result.isBlank ? blankResult(display)(value, record, props) : display(value, record, props);
let TableBody = ({
  node,
  tree,
  visibleFields,
  fields,
  hiddenFields,
  getRowKey = _.get("_id"),
  blankRows,
  pageSize,
  stickyColumn,
  theme: { Tbody, Tr, Td, Loader = StripedLoader },
  Row = Tr,
  NoResultsComponent,
  IntroComponent,
  defaultDisplay = displayCell
}) => {
  let results = blankRows ? addBlankRows(getResults(node), pageSize, "_id") : getResults(node);
  let hasResults = _.get("length", results);
  let showLoader = node.updating;
  let showIntro = !showLoader && !hasResults && !node.lastUpdateTime;
  let showNoResults = !showLoader && !showIntro && !hasResults;
  return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(
    Tbody,
    {
      style: {
        display: showIntro || showNoResults ? "none" : ""
      }
    },
    !_.isEmpty(results) && _.map(
      (x) => /* @__PURE__ */ React.createElement(
        Row,
        {
          key: getRowKey(x),
          record: getRecord(x),
          ...{ fields, visibleFields, hiddenFields }
        },
        _.map(
          ({
            field,
            display = (x2) => x2,
            Cell = Td,
            cellProps: { className, style, ...cellProps } = {}
          }) => /* @__PURE__ */ React.createElement(
            Cell,
            {
              key: field,
              className: `${field === stickyColumn ? "sticky-column" : ""} ${className}`,
              style: {
                position: field === stickyColumn ? "sticky" : "",
                left: field === stickyColumn ? 0 : "",
                ...style
              },
              ...cellProps
            },
            defaultDisplay({
              display,
              value: _.get(field, getRecord(x)),
              record: getRecord(x),
              result: x,
              tree,
              node
            })
          ),
          visibleFields
        )
      ),
      results
    )
  ), /* @__PURE__ */ React.createElement(
    Tbody,
    {
      style: {
        display: showIntro || showLoader || showNoResults ? "" : "none"
      }
    },
    /* @__PURE__ */ React.createElement(Tr, null, /* @__PURE__ */ React.createElement(Td, { colSpan: visibleFields.length, style: { padding: 0 } }, /* @__PURE__ */ React.createElement(Loader, { loading: showLoader }, (showLoader || showIntro) && IntroComponent, showNoResults && NoResultsComponent)))
  ));
};
var TableBody_default = _.flow(observer, withTheme)(TableBody);
export {
  TableBody_default as default
};
