import React from "react";
import _ from "lodash/fp.js";
import F from "futil";
import { fieldsToOptions } from "../../utils/fields.js";
import { contexturifyWithoutLoader } from "../../utils/hoc.js";
import { applyDefaults, inferSchema } from "../../utils/schema.js";
import { newNodeFromField } from "../../utils/search.js";
import Header from "./Header.js";
import TableBody from "./TableBody.js";
import ResultTableFooter from "./ResultTableFooter.js";
import { withTheme } from "../../utils/theme.js";
let getIncludes = (schema, node) => F.when(_.isEmpty, _.map("field", schema))(node.include);
let DefaultRow = withTheme(({ theme: { Tr = "tr" }, ...props }) => /* @__PURE__ */ React.createElement(
  Tr,
  {
    ..._.omit(["record", "fields", "visibleFields", "hiddenFields"], props)
  }
));
let ResultTable = ({
  fields,
  infer,
  path,
  criteria,
  node = {},
  tree,
  defaultDisplay,
  NoResultsComponent = "No Results Found",
  IntroComponent = null,
  // Initial component to be shown instead of the grid when no data has been loaded
  Row = DefaultRow,
  // accept a custom Row component so we can do fancy expansion things
  getRowKey,
  // allow passing a custom function to generate unique row key
  mapNodeToProps = () => ({}),
  pageSizeOptions,
  // an array of options to set the # of rows per page (default [20, 50, 100, 250])
  limitedResults,
  stickyColumn,
  hideFooter,
  footerStyle,
  theme
}) => {
  const { Table, Thead, Tr, Th } = theme;
  if (_.isEmpty(fields) && !infer)
    throw new Error("Fields are empty");
  let mutate = tree.mutate(path);
  let resultsLength = F.cascade(
    ["context.response.results.length", "context.results.length"],
    node
  );
  let totalRecords = F.cascade(
    ["context.response.totalRecords", "context.totalRecords"],
    node
  );
  let blankRows = limitedResults && resultsLength < node.pageSize && totalRecords > resultsLength;
  let schema = _.flow(
    _.merge(infer && inferSchema(node)),
    applyDefaults,
    _.values,
    _.orderBy("order", "desc")
  )(fields);
  let includes = getIncludes(schema, node);
  let isIncluded = (x) => _.includes(x.field, includes);
  let visibleFields = _.flow(
    _.map((field) => _.find({ field }, schema)),
    _.compact
  )(includes);
  let hiddenFields = _.reject(isIncluded, schema);
  let headerProps = {
    mapNodeToProps,
    fields,
    visibleFields,
    includes,
    addOptions: fieldsToOptions(hiddenFields),
    addFilter: (field) => tree.add(criteria, newNodeFromField({ field, fields })),
    tree,
    node,
    mutate,
    criteria,
    theme
  };
  let columnGroupsHeight = _.flow(
    _.map("fieldGroup.length"),
    _.max
  )(visibleFields);
  let columnGroups = _.reduce(
    (columnGroups2, { fieldGroup, headerCellProps, HeaderCell, HeaderGroup }) => {
      for (let i = 0; i < columnGroupsHeight; i++) {
        let groupRow = columnGroups2[i] || (columnGroups2[i] = []);
        let groupName = _.getOr("", i, fieldGroup);
        let lastGroup = _.last(groupRow);
        if (_.get("groupName", lastGroup) === groupName) {
          lastGroup.colspan++;
          lastGroup.HeaderCell = HeaderCell;
        } else
          groupRow.push({
            groupName,
            colspan: 1,
            headerCellProps,
            HeaderCell,
            HeaderGroup
          });
      }
      return columnGroups2;
    },
    [],
    visibleFields
  );
  return /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(Table, { "data-path": node.path }, /* @__PURE__ */ React.createElement(Thead, null, F.mapIndexed(
    (columnGroupRow, i) => /* @__PURE__ */ React.createElement(Tr, { key: i }, F.mapIndexed(
      ({
        groupName,
        colspan,
        headerCellProps,
        HeaderCell = Th,
        HeaderGroup
      }, j) => /* @__PURE__ */ React.createElement(HeaderCell, { key: j, colSpan: colspan, ...headerCellProps }, HeaderGroup ? /* @__PURE__ */ React.createElement(HeaderGroup, null, groupName) : groupName),
      columnGroupRow
    )),
    columnGroups
  ), /* @__PURE__ */ React.createElement(Tr, null, F.mapIndexed(
    (x, i) => /* @__PURE__ */ React.createElement(
      Header,
      {
        key: x.field,
        field: x,
        isLastColumn: i === visibleFields.length - 1,
        isStickyColumn: stickyColumn && x.field === stickyColumn,
        ...headerProps
      }
    ),
    visibleFields
  ))), /* @__PURE__ */ React.createElement(
    TableBody,
    {
      ...{
        node,
        tree,
        fields,
        visibleFields,
        hiddenFields,
        schema,
        Row,
        getRowKey,
        blankRows,
        pageSize: Math.min(node.pageSize, totalRecords),
        stickyColumn,
        NoResultsComponent,
        IntroComponent,
        defaultDisplay
      }
    }
  )), !hideFooter && node.pageSize > 0 && /* @__PURE__ */ React.createElement(
    ResultTableFooter,
    {
      ...{
        tree,
        node,
        path,
        pageSizeOptions,
        disabled: blankRows,
        style: footerStyle
      }
    }
  ));
};
var ResultTable_default = contexturifyWithoutLoader(ResultTable);
export {
  ResultTable_default as default
};
