import React from "react";
import _ from "lodash/fp.js";
import F from "futil";
import { observer } from "mobx-react";
import { withTheme } from "../../utils/theme.js";
import { getTag, tagTerm, tagValueField } from "./utils.js";
let TagActionsMenu = ({
  tag,
  node,
  tree,
  onChange,
  theme: { Button, Checkbox, RadioList }
}) => {
  let tagInstance = getTag(tag, node);
  return /* @__PURE__ */ React.createElement(
    "div",
    {
      className: "tags-query-tag-actions-menu",
      style: { minWidth: 100, padding: 10 }
    },
    /* @__PURE__ */ React.createElement("div", null, _.startCase(tagTerm), ":", " ", /* @__PURE__ */ React.createElement("span", { className: "filter-field-label" }, tag)),
    _.includes(" ", tag) && /* @__PURE__ */ React.createElement("div", { style: { margin: "10px 0" } }, /* @__PURE__ */ React.createElement(
      RadioList,
      {
        options: F.autoLabelOptions(["fuzzy", "exact"]),
        value: tagInstance.distance ? "fuzzy" : "exact",
        onChange: (value) => {
          tagInstance.distance = value === "fuzzy" ? 3 : 0;
          tree.mutate(node.path, { tags: [...node.tags] });
          F.maybeCall(onChange);
        }
      }
    ), /* @__PURE__ */ React.createElement(
      Button,
      {
        onClick: () => {
          tree.mutate(node.path, {
            tags: _.map((tag2) => {
              if (_.includes(" ", tag2[tagValueField]))
                tag2.distance = tagInstance.distance;
              return tag2;
            }, node.tags)
          });
          F.maybeCall(onChange);
        }
      },
      "Apply to all ",
      tagTerm,
      "s"
    )),
    /* @__PURE__ */ React.createElement("label", { className: "labeled-checkbox", style: { marginTop: 15 } }, /* @__PURE__ */ React.createElement(
      Checkbox,
      {
        checked: tagInstance.onlyShowTheseResults,
        onChange: (e) => {
          tagInstance.onlyShowTheseResults = e.target.checked;
          tree.mutate(node.path, { tags: [...node.tags] });
          F.maybeCall(onChange);
        }
      }
    ), /* @__PURE__ */ React.createElement("span", null, "Only view this ", tagTerm))
  );
};
var TagActionsMenu_default = _.flow(observer, withTheme)(TagActionsMenu);
export {
  TagActionsMenu_default as default
};
