import React from "react";
import F from "futil";
import _ from "lodash/fp.js";
import { observer } from "mobx-react";
import { useOutsideClick } from "@chakra-ui/react-use-outside-click";
import { withNode } from "../utils/hoc.js";
import { Box, ButtonGroup, Button, StripedLoader } from "../greyVest/index.js";
import ExpandableTagsInput, { Tags } from "../greyVest/ExpandableTagsInput.js";
import ExpandableTagsQuery from "./ExpandableTagsQuery/index.js";
let searchBarStyle = {
  overflow: "visible"
  // for the search button animation
};
let searchBarBoxStyle = {
  padding: "8px 10px",
  flex: 1,
  borderBottomRightRadius: "3px"
};
let innerEdgeMargins = {
  marginRight: "-10px",
  marginLeft: "-10px",
  marginTop: "-8px",
  marginBottom: "-8px"
};
let inputStyle = {
  border: "none"
};
let buttonStyle = {
  boxShadow: "0 2px 10px 0 rgba(39, 44, 65, 0.1)",
  fontSize: 18,
  maxHeight: 56
};
let AnimatedButton = ({ disabled, style, className, ...props }) => /* @__PURE__ */ React.createElement(
  Button,
  {
    className: `${disabled ? "disabled" : "animated pulse infinite"} ${className || ""}`,
    style: {
      ...style,
      ...disabled ? { backgroundColor: "#80BBEF" } : {},
      animationDuration: "500ms"
    },
    primary: true,
    ...props
  }
);
let SearchButton = observer(({ tree, searchButtonProps }) => /* @__PURE__ */ React.createElement(
  AnimatedButton,
  {
    disabled: !tree?.tree?.markedForUpdate,
    onClick: tree.triggerUpdate,
    style: buttonStyle,
    ...searchButtonProps
  },
  "Search"
));
let SearchBar = ({
  tree,
  node,
  actionWrapper,
  searchButtonProps,
  tagsQueryProps,
  enableKeywordGenerations
}) => {
  let collapse = React.useState(true);
  let ref = React.useRef();
  let hasPopover = React.useRef(false);
  useOutsideClick({
    ref,
    handler: () => !hasPopover.current && F.on(collapse)()
  });
  return /* @__PURE__ */ React.createElement(
    ButtonGroup,
    {
      ref,
      "data-path": node.path,
      style: searchBarStyle,
      onMouseUp: (e) => {
        e.stopPropagation();
      }
    },
    /* @__PURE__ */ React.createElement(Box, { style: searchBarBoxStyle, onClick: F.off(collapse) }, /* @__PURE__ */ React.createElement(
      ExpandableTagsQuery,
      {
        ...{
          tree,
          node,
          collapse,
          hasPopover,
          actionWrapper,
          enableKeywordGenerations,
          innerEdgeMargins
        },
        onAddTag: F.off(collapse),
        Loader: ({ children, ...props }) => /* @__PURE__ */ React.createElement(StripedLoader, { ...props }, children),
        style: inputStyle,
        theme: {
          TagsInput: F.view(collapse) && !_.isEmpty(node.tags) ? Tags : ExpandableTagsInput
        },
        autoFocus: !hasPopover.current,
        ...tagsQueryProps
      }
    )),
    tree.disableAutoUpdate && /* @__PURE__ */ React.createElement(SearchButton, { tree, searchButtonProps })
  );
};
var TagsQuerySearchBar_default = _.flow(observer, withNode)(SearchBar);
export {
  TagsQuerySearchBar_default as default
};
