import _ from "lodash/fp.js";
import F from "futil";
import React from "react";
import { observer } from "mobx-react";
import { contexturify } from "../utils/hoc.js";
import { withTheme } from "../utils/theme.js";
import { ExpandableTable, Column, Flex } from "../greyVest/index.js";
import { setDisplayName } from "react-recompose";
let toolBarStyle = { justifyContent: "space-between", alignItems: "center" };
let SimpleLabel = ({ text }) => /* @__PURE__ */ React.createElement("label", { style: { paddingRight: "5px" } }, text);
let SimpleFilter = _.flow(
  setDisplayName("SimpleFilter"),
  observer,
  withTheme
)(({ theme: { TextInput }, ...props }) => /* @__PURE__ */ React.createElement(Flex, { style: { ...toolBarStyle, width: "75%" } }, /* @__PURE__ */ React.createElement(SimpleLabel, { text: "Filter:" }), /* @__PURE__ */ React.createElement(TextInput, { ...props })));
let SelectSize = _.flow(
  setDisplayName("SelectSize"),
  observer,
  withTheme
)(
  ({
    node,
    tree,
    options = [10, 25, 50, 100, 500, 1e3],
    theme: { Select }
  }) => /* @__PURE__ */ React.createElement(Flex, { style: { marginLeft: 12, ...toolBarStyle } }, /* @__PURE__ */ React.createElement(SimpleLabel, { text: "Size:" }), /* @__PURE__ */ React.createElement(
    Select,
    {
      onChange: (e) => {
        tree.mutate(node.path, { size: e.target.value });
      },
      value: _.getOr(25, "size", node),
      placeholder: null,
      style: { width: "100px" },
      options: _.map((x) => ({ value: x, label: x }), options)
    }
  ))
);
let TermsStatsTable = ({
  node,
  criteria,
  criteriaField,
  criteriaFieldLabel = "",
  criteriaGetValue = _.identity,
  tree,
  children,
  sizeOptions,
  limitedResults,
  theme: { Button },
  ...props
}) => /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement(Flex, { style: { ...toolBarStyle, margin: "0 8px" } }, /* @__PURE__ */ React.createElement(SimpleFilter, { ...F.domLens.value(tree.lens(node.path, "filter")) }), /* @__PURE__ */ React.createElement(SelectSize, { node, tree, options: sizeOptions })), /* @__PURE__ */ React.createElement(
  ExpandableTable,
  {
    ...{
      ...props,
      children: criteria ? [
        ..._.compact(children),
        /* @__PURE__ */ React.createElement(
          Column,
          {
            key: "checkbox",
            label: criteriaFieldLabel,
            expand: {
              display: (value, record) => /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement(
                Button,
                {
                  onClick: async () => {
                    let field = criteriaField || node.key_field || node.groupField;
                    let filter = criteria && _.find({ field }, tree.getNode(criteria).children);
                    if (!filter || _.get("mode", filter) === "exclude") {
                      await tree.add(criteria, {
                        field,
                        type: "facet"
                      });
                      filter = _.findLast(
                        { field },
                        tree.getNode(criteria).children
                      );
                    }
                    await tree.mutate(filter.path, {
                      mode: "include",
                      values: _.uniq([
                        ..._.getOr([], "values", filter),
                        criteriaGetValue(record.key)
                      ])
                    });
                  }
                },
                "Add as Filter"
              ))
            }
          }
        )
      ] : _.compact(children)
    },
    data: node.context?.terms ?? node.context?.results,
    sortField: node.order,
    sortDir: node.sortDir,
    columnSort: (column) => {
      if (column.field !== "key" && column.enableSort) {
        tree.mutate(node.path, {
          order: column.field,
          sortDir: column.sortDir
        });
      }
    },
    blankRows: limitedResults,
    pageSize: node.size
  }
));
var TermsStatsTable_default = contexturify(TermsStatsTable);
export {
  TermsStatsTable_default as default
};
