import _ from "lodash/fp.js";
import F from "futil";
import React from "react";
import { observable } from "../utils/mobx.js";
import { observer, inject } from "mobx-react";
import { DropdownItem } from "./DropdownItem.js";
import Popover from "./Popover.js";
import Table from "./Table.js";
import { addBlankRows, blankResult } from "../utils/format.js";
import { withTheme } from "../utils/theme.js";
let Column = _.identity;
Column.displayName = "Column";
let ExpandedSection = observer(
  ({ columnCount, expandedRow }) => _.getOr(null, "details.Component", expandedRow) && /* @__PURE__ */ React.createElement("tr", { align: "center" }, /* @__PURE__ */ React.createElement("td", { colSpan: columnCount }, expandedRow.details.Component(
    _.get(expandedRow.field, expandedRow.record),
    expandedRow.record
  )))
);
let TableBodyState = () => {
  let state = {
    expanded: observable(/* @__PURE__ */ new Map()),
    onClick(field, keyField, record, index, details) {
      let key = record[keyField];
      let indexedField = `${field}${index}`;
      if (_.get("indexedField", state.expanded.get(key)) !== indexedField && !record.isBlank) {
        state.expanded.set(key, {
          key,
          record,
          field,
          indexedField,
          details
        });
      } else {
        state.expanded.delete(key);
      }
    }
  };
  return state;
};
let TableBody = inject(TableBodyState)(
  observer(
    ({ data, columns, recordKey, expanded, onClick, blankRows, pageSize }) => {
      let rows = blankRows ? addBlankRows(data, pageSize, recordKey) : data;
      return /* @__PURE__ */ React.createElement("tbody", null, _.map(
        (x) => /* @__PURE__ */ React.createElement(React.Fragment, { key: x[recordKey] }, /* @__PURE__ */ React.createElement(
          "tr",
          {
            ...x.rowAttrs,
            className: _.getOr("", "rowAttrs.className", x) + (expanded.has(x[recordKey]) ? "expanded" : "")
          },
          F.mapIndexed(
            ({ field, display = (x2) => x2, details = {} }, i) => /* @__PURE__ */ React.createElement(
              "td",
              {
                key: `${field}${i}`,
                ...!_.isEmpty(details) && {
                  style: {
                    cursor: !_.isEmpty(details) ? "pointer" : "auto"
                  },
                  onClick: () => onClick(field, recordKey, x, i, details, expanded)
                }
              },
              F.when(
                () => x.isBlank,
                blankResult,
                _.getOr(
                  display,
                  `${_.isEqual(
                    _.get(
                      "indexedField",
                      expanded.get(x[recordKey])
                    ),
                    `${field}${i}`
                  ) ? "collapse" : "expand"}.display`,
                  details
                )
              )(_.get(field, x), x)
            ),
            columns
          )
        ), expanded.has(x[recordKey]) && /* @__PURE__ */ React.createElement(
          ExpandedSection,
          {
            expandedRow: expanded.get(x[recordKey]),
            columnCount: columns.length
          }
        )),
        rows
      ));
    }
  )
);
let TableState = (stores, props) => ({
  columns: _.map(
    ({ props: props2 }) => ({
      ..._.pick(["field", "label", "display", "enableSort"], props2),
      details: F.compactObject({
        ..._.pick(["expand", "collapse"], props2),
        Component: props2.children
      })
    }),
    _.castArray(props.children)
  )
});
let ExpandableTable = inject(TableState)(
  observer(
    ({
      data,
      columns,
      recordKey = "key",
      columnSort = _.identity,
      theme: { Icon },
      ...props
    }) => /* @__PURE__ */ React.createElement(Table, { ...props.tableAttrs }, /* @__PURE__ */ React.createElement("thead", null, /* @__PURE__ */ React.createElement("tr", null, F.mapIndexed(
      (c, i) => /* @__PURE__ */ React.createElement(
        "th",
        {
          key: `${c.field}${i}`,
          ...c.enableSort && {
            style: { cursor: "pointer" }
          }
        },
        /* @__PURE__ */ React.createElement("span", null, F.callOrReturn(_.getOr(F.autoLabel(c.field), "label", c)), c.enableSort && /* @__PURE__ */ React.createElement(
          Popover,
          {
            trigger: /* @__PURE__ */ React.createElement(Icon, { icon: "TableColumnMenu" }),
            position: `bottom ${i === columns.length - 1 ? "right" : "center"}`,
            style: {
              userSelect: "none",
              width: "auto"
            }
          },
          /* @__PURE__ */ React.createElement(
            DropdownItem,
            {
              onClick: () => columnSort({ ...c, sortDir: "asc" })
            },
            /* @__PURE__ */ React.createElement(Icon, { icon: "SortAscending" }),
            "Sort Ascending"
          ),
          /* @__PURE__ */ React.createElement(
            DropdownItem,
            {
              onClick: () => columnSort({ ...c, sortDir: "desc" })
            },
            /* @__PURE__ */ React.createElement(Icon, { icon: "SortDescending" }),
            "Sort Descending"
          )
        ))
      ),
      columns
    ))), /* @__PURE__ */ React.createElement(
      TableBody,
      {
        columns,
        data,
        recordKey,
        ...props
      }
    ))
  )
);
ExpandableTable.displayName = "ExpandableTable";
var ExpandableTable_default = withTheme(ExpandableTable);
export {
  Column,
  ExpandableTable_default as default
};
