import React from "react";
import _ from "lodash/fp.js";
import { observer } from "mobx-react";
import { Tag as DefaultTag, Flex } from "./index.js";
import { createTags } from "./utils.js";
let Tags = ({
  reverse = false,
  tags,
  removeTag,
  tagStyle,
  onTagClick = _.noop,
  Tag = DefaultTag
}) => /* @__PURE__ */ React.createElement(
  Flex,
  {
    wrap: true,
    alignItems: "center",
    style: {
      cursor: "text",
      margin: "0 -2px"
    }
  },
  _.flow(
    reverse ? _.reverse : _.identity,
    _.map((t) => /* @__PURE__ */ React.createElement(
      Tag,
      {
        key: t,
        value: t,
        ...{ removeTag, tagStyle },
        onClick: () => onTagClick(t)
      }
    ))
  )(tags)
);
let isValidInput = (tag, tags) => !_.isEmpty(tag) && !_.includes(tag, tags);
let ExpandableTagsInput = ({
  tags,
  addTags: setTags,
  removeTag,
  submit = _.noop,
  tagStyle,
  placeholder = "Search...",
  splitCommas,
  style,
  autoFocus,
  onBlur = _.noop,
  onInputChange = _.noop,
  onTagClick = _.noop,
  sanitizeTagFn,
  Tag = DefaultTag,
  ...props
}) => {
  let [currentInput, setCurrentInput] = React.useState("");
  let addTags = (input) => {
    let newTags = createTags({ input, splitCommas, sanitizeTagFn });
    setTags(_.difference(newTags, tags));
  };
  return /* @__PURE__ */ React.createElement("div", { style }, /* @__PURE__ */ React.createElement("span", { className: "tags-input-container" }, /* @__PURE__ */ React.createElement(
    "input",
    {
      style: { flex: 1, border: 0 },
      ref: autoFocus ? (input) => input && input.focus() : void 0,
      onChange: (e) => {
        setCurrentInput(e.target.value);
        onInputChange();
      },
      onBlur: () => {
        if (isValidInput(currentInput, tags)) {
          addTags(currentInput);
          setCurrentInput("");
          onBlur();
        }
      },
      onKeyDown: (e) => {
        if (e.key === "Enter" && !currentInput)
          submit();
        if ((_.includes(e.key, ["Enter", "Tab"]) || splitCommas && e.key === ",") && isValidInput(currentInput, tags)) {
          addTags(currentInput);
          setCurrentInput("");
          e.preventDefault();
        }
        if (e.key === "Backspace" && !currentInput && tags.length) {
          let last = _.last(tags);
          removeTag(last);
          setCurrentInput(last);
          e.preventDefault();
        }
      },
      value: currentInput,
      placeholder,
      ..._.omit(["onTagsDropped", "maxTags", "Loader"], props)
    }
  ), /* @__PURE__ */ React.createElement(Tags, { reverse: true, ...{ tags, removeTag, tagStyle, onTagClick, Tag } })));
};
var ExpandableTagsInput_default = observer(ExpandableTagsInput);
export {
  Tags,
  ExpandableTagsInput_default as default
};
