import React from "react";
import F from "futil";
import _ from "lodash/fp.js";
import { setDisplayName } from "react-recompose";
import { inject, observer, Observer } from "mobx-react";
import { observable } from "../utils/mobx.js";
import { withTheme } from "../utils/theme.js";
import pluralize from "pluralize";
import Flex from "./Flex.js";
import GVTextInput from "./TextInput.js";
import GVTextHighlight from "./TextHighlight.js";
import { isField } from "../utils/fields.js";
let PickerContext = React.createContext();
let unflattenObjectBy = _.curry(
  (iteratee, x) => _.zipObjectDeep(F.mapIndexed(iteratee, x), _.values(x))
);
let getNonFieldItemLabel = F.unless(_.includes(" "), _.startCase);
let getItemLabel = (item) => isField(item) ? F.cascade(["shortLabel", "label"], item) : getNonFieldItemLabel(item._key);
let toNested = _.flow(
  _.map((x) => _.defaults({ path: x.value }, x)),
  (fields) => [
    ..._.map(
      (field) => ({
        ...field,
        // flatten path of fields for this group after "CommonlyUsedFields"
        path: `CommonlyUsedFields.${_.camelCase(field.path)}`
      }),
      _.filter("isCommonlyUsed", fields)
    ),
    ...fields
  ],
  unflattenObjectBy("path")
);
let FilteredSection = _.flow(
  setDisplayName("FilteredSection"),
  observer
)(
  ({
    options,
    highlight,
    style = { maxHeight: 340, overflowY: "scroll" },
    checked
  }) => {
    let { PickerItem, TextHighlight, setHoverItem } = React.useContext(PickerContext);
    return /* @__PURE__ */ React.createElement("div", { style }, F.mapIndexed(
      (option, field) => /* @__PURE__ */ React.createElement(
        PickerItem,
        {
          key: field,
          isChecked: checked.has(option.value),
          onClick: () => {
            checked.has(option.value) ? checked.delete(option.value) : checked.set(option.value, option);
          },
          ...F.domLens.hover(
            (isHover) => setHoverItem(isHover ? option : null)
          )
        },
        /* @__PURE__ */ React.createElement(TextHighlight, { text: option.label, pattern: highlight })
      ),
      options
    ));
  }
);
let Section = _.flow(
  setDisplayName("Section"),
  observer
)(
  ({
    options,
    onClick,
    selected,
    checked,
    style = { overflow: "auto", width: "100%", maxHeight: 300 }
  }) => {
    let { PickerItem, setHoverItem } = React.useContext(PickerContext);
    return /* @__PURE__ */ React.createElement("div", { style }, _.map(
      (item) => /* @__PURE__ */ React.createElement(
        PickerItem,
        {
          key: item._key,
          onClick: () => onClick(
            _.isString(item.value) && item.value || item._key,
            item
          ),
          active: selected === item._key,
          hasChildren: !isField(item),
          isChecked: checked.has(item.value),
          ...F.domLens.hover(
            (isHover) => setHoverItem(isHover ? item : null)
          )
        },
        getItemLabel(item)
      ),
      _.flow(F.unkeyBy("_key"), _.sortBy(getItemLabel))(options)
    ));
  }
);
let PanelTreePicker = inject((store, { options, checked }) => {
  let x = {
    checked,
    state: observable({ selected: [] }),
    nestedOptions: toNested(options),
    selectAtLevel: _.curry((level, key, field) => {
      if (isField(field)) {
        checked.has(field.value) ? checked.delete(field.value) : checked.set(field.value, field);
      } else {
        x.state.selected.splice(level, x.state.selected.length - level, key);
      }
    })
  };
  return x;
})(
  observer(({ selectAtLevel, state, nestedOptions, checked }) => /* @__PURE__ */ React.createElement(
    "div",
    {
      className: "panel-tree-picker",
      style: { display: "inline-flex", width: "100%" }
    },
    /* @__PURE__ */ React.createElement(
      Section,
      {
        checked,
        options: nestedOptions,
        onClick: selectAtLevel(0),
        selected: state.selected[0]
      }
    ),
    F.mapIndexed(
      (_key, index) => /* @__PURE__ */ React.createElement(
        Section,
        {
          key: index,
          checked,
          options: _.get(state.selected.slice(0, index + 1), nestedOptions),
          onClick: selectAtLevel(index + 1),
          selected: state.selected[index + 1]
        }
      ),
      state.selected
    )
  ))
);
PanelTreePicker.displayName = "PanelTreePicker";
let matchLabel = (str) => _.filter((x) => F.matchAllWords(str)(x.label));
let NestedPicker = ({
  options,
  onChange,
  PickerItem = "div",
  TextInput = GVTextInput,
  TextHighlight = GVTextHighlight,
  itemType = "filter",
  style = {},
  theme: { Button }
}) => {
  let [state] = React.useState(
    () => observable({
      filter: "",
      checked: /* @__PURE__ */ new Map(),
      hoverItem: null,
      get hasItemDescription() {
        return _.flow(_.trim, F.isNotBlank)(state.hoverItem?.description);
      }
    })
  );
  let showDescriptionPanel = _.some("description", options);
  return /* @__PURE__ */ React.createElement(
    PickerContext.Provider,
    {
      value: {
        PickerItem,
        TextHighlight,
        setHoverItem: _.debounce(100, (item) => state.hoverItem = item)
      }
    },
    /* @__PURE__ */ React.createElement(Flex, { style }, showDescriptionPanel && /* @__PURE__ */ React.createElement(Observer, null, () => /* @__PURE__ */ React.createElement(
      Flex,
      {
        alignItems: "center",
        className: "gv-picker-description-container",
        style: {
          flexShrink: 0,
          flexBasis: 200,
          paddingLeft: 16,
          paddingRight: 16,
          textAlign: state.hasItemDescription ? "left" : "center"
        }
      },
      state.hasItemDescription ? /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement("em", null, /* @__PURE__ */ React.createElement("h4", null, state.hoverItem.label)), /* @__PURE__ */ React.createElement("em", null, state.hoverItem.description)) : /* @__PURE__ */ React.createElement("em", null, "Hover over a field to view the description")
    )), /* @__PURE__ */ React.createElement("div", { style: { padding: 16, flexGrow: 1 } }, /* @__PURE__ */ React.createElement(Observer, null, () => /* @__PURE__ */ React.createElement(React.Fragment, null, /* @__PURE__ */ React.createElement(
      TextInput,
      {
        style: { marginBottom: 10 },
        value: state.filter,
        onChange: (e) => state.filter = e.target.value,
        placeholder: "Enter filter keyword..."
      }
    ), state.filter ? /* @__PURE__ */ React.createElement(
      FilteredSection,
      {
        checked: state.checked,
        highlight: state.filter,
        options: matchLabel(state.filter)(options)
      }
    ) : /* @__PURE__ */ React.createElement(PanelTreePicker, { options, checked: state.checked }))), /* @__PURE__ */ React.createElement(Flex, { justifyContent: "space-between", style: { marginTop: 20 } }, /* @__PURE__ */ React.createElement(
      Button,
      {
        onClick: () => {
          state.checked = /* @__PURE__ */ new Map();
          onChange();
        }
      },
      "Cancel"
    ), /* @__PURE__ */ React.createElement(Observer, null, () => !!state.checked.size && /* @__PURE__ */ React.createElement(
      Button,
      {
        primary: true,
        onClick: () => onChange(Array.from(state.checked.values()))
      },
      "Add",
      " ",
      `${state.checked.size} ${pluralize(
        itemType,
        state.checked.size
      )}`
    )))))
  );
};
var NestedPicker_default = withTheme(NestedPicker);
export {
  NestedPicker_default as default
};
