import React from "react";
import _ from "lodash/fp.js";
import F from "futil";
import Pager from "./Pager.js";
import PagerItem from "./PagerItem.js";
import PageSize from "./PageSize.js";
import Flex from "./Flex.js";
import { toNumber } from "../utils/format.js";
let PageDetails = ({ startRecord, endRecord, totalRecords, hasMore }) => /* @__PURE__ */ React.createElement("span", { style: { flex: "0 1 30%", textAlign: "right" } }, /* @__PURE__ */ React.createElement("b", null, "Showing "), startRecord >= endRecord ? endRecord : `${toNumber(startRecord)}-${toNumber(endRecord)}`, F.isNotNil(totalRecords) && ` of ${toNumber(totalRecords)}${hasMore ? "+" : ""}`);
let TableFooter = ({
  page = 1,
  onChangePage,
  pageSize,
  onChangePageSize,
  pageSizeOptions,
  hasMore,
  totalRecords,
  startRecord = pageSize * (page - 1) + 1,
  endRecord = hasMore ? page * pageSize : 0,
  disabled = false,
  ...props
}) => {
  if (totalRecords)
    endRecord = endRecord || _.min([page * pageSize, totalRecords]);
  if (!hasMore && !totalRecords)
    totalRecords = endRecord;
  let pageCount = _.ceil((totalRecords || endRecord) / pageSize);
  return /* @__PURE__ */ React.createElement(
    Flex,
    {
      className: "gv-table-footer",
      justifyContent: "space-between",
      alignItems: "center",
      ...props
    },
    /* @__PURE__ */ React.createElement(
      PageSize,
      {
        sizeOptions: pageSizeOptions,
        value: pageSize,
        onChange: onChangePageSize,
        style: { flex: "0 1 30%" }
      }
    ),
    /* @__PURE__ */ React.createElement(Flex, { style: { flex: 1 }, alignItems: "center", justifyContent: "center" }, /* @__PURE__ */ React.createElement(
      Pager,
      {
        disabled,
        value: page,
        onChange: onChangePage,
        pageCount
      }
    ), hasMore && page >= pageCount && /* @__PURE__ */ React.createElement(
      PagerItem,
      {
        disabled,
        style: { margin: "0 8px", paddingLeft: 12, paddingRight: 12 },
        onClick: () => onChangePage(page + 1)
      },
      "Load More..."
    )),
    totalRecords > 0 && /* @__PURE__ */ React.createElement(PageDetails, { ...{ totalRecords, startRecord, endRecord, hasMore } })
  );
};
var TableFooter_default = TableFooter;
export {
  TableFooter_default as default
};
