import _ from "lodash/fp.js";
import F from "futil";
import { queryStringCharacterBlacklist } from "contexture-util/exampleTypes/tagsQuery.js";
import escapeStringRegexp from "escape-string-regexp";
let openBinding = (...lens) => ({
  isOpen: F.view(...lens),
  onClose: F.off(...lens)
});
let maxWordsPerTag = 100;
let maxCharsPerTagWord = 100;
let wordRegexp = new RegExp(
  `[^${escapeStringRegexp(queryStringCharacterBlacklist)}]+`,
  "g"
);
let words = _.words.convert({ fixed: false });
let sanitizeQueryStringTag = _.flow(
  (string) => words(string, wordRegexp),
  _.take(maxWordsPerTag),
  _.map(
    (word) => _.flow(
      _.truncate({ length: maxCharsPerTagWord, omission: "" }),
      // Remove beginning of line dash and space dash
      // https://github.com/smartprocure/spark/issues/10923
      _.replace(/^-| -/g, " "),
      _.trim
    )(word)
  ),
  _.join(" ")
);
let splitTagOnComma = _.flow(
  _.split(","),
  _.invokeMap("trim"),
  _.compact,
  _.uniq
);
let createTags = ({ input, splitCommas, sanitizeTagFn }) => _.flow(
  _.trim,
  splitCommas ? splitTagOnComma : _.identity,
  _.castArray,
  sanitizeTagFn ? _.map(sanitizeTagFn) : _.identity,
  _.map(_.trim),
  _.compact
)(input);
export {
  createTags,
  openBinding,
  sanitizeQueryStringTag
};
