import F from "futil";
import _ from "lodash/fp.js";
import React from "react";
import { observer } from "mobx-react";
import { Dynamic, Grid } from "../greyVest/index.js";
import { ModalPicker } from "../purgatory/index.js";
import { fieldsToOptions } from "../utils/fields.js";
import { get } from "../utils/mobx-utils.js";
import {
  newNodeFromType,
  newNodeFromField,
  transformNodeFromField,
  getTypeLabelOptions
} from "../utils/search.js";
import { withTheme } from "../utils/theme.js";
let FilterContents = ({
  node,
  tree,
  fields,
  mapNodeToProps = _.noop,
  style,
  theme: { Select, UnmappedNodeComponent }
}) => {
  let nodeField = get(node, "field");
  let typeOptions = _.get([nodeField, "typeOptions"], fields) || [];
  if (node.type && !_.includes(node.type, typeOptions))
    typeOptions = [...typeOptions, node.type];
  let nodeLabel = _.get([nodeField, "label"], fields) || nodeField;
  return /* @__PURE__ */ React.createElement(Grid, { columns: "auto auto minmax(0, 1fr)", style }, /* @__PURE__ */ React.createElement(
    ModalPicker,
    {
      label: nodeField ? nodeLabel : "Pick a Field",
      options: fieldsToOptions(fields),
      onChange: (addedFields) => {
        addedFields = _.castArray(addedFields);
        if (addedFields[0])
          tree.replace(
            node.path,
            transformNodeFromField({ field: addedFields[0].field, fields })
          );
        _.each(
          ({ field }) => tree.add(
            node.path.slice(0, -1),
            newNodeFromField({ field, fields })
          ),
          addedFields.slice(1)
        );
      }
    }
  ), nodeField && /* @__PURE__ */ React.createElement("div", { style: { margin: "0 5px" } }, /* @__PURE__ */ React.createElement(
    Select,
    {
      onChange: ({ target: { value: type } }) => {
        tree.replace(node.path, newNodeFromType(type, fields, node));
      },
      placeholder: "Select Type",
      value: F.when(_.isNil, void 0)(node.type),
      options: getTypeLabelOptions(tree, typeOptions)
    }
  )), node.type && /* @__PURE__ */ React.createElement(
    "div",
    {
      style: {
        display: "inline-block",
        verticalAlign: "top",
        width: "100%",
        marginRight: "5px"
      }
    },
    /* @__PURE__ */ React.createElement(
      Dynamic,
      {
        ...{
          component: UnmappedNodeComponent,
          tree,
          node,
          ...mapNodeToProps(node, fields)
        }
      }
    )
  ));
};
var FilterContents_default = _.flow(observer, withTheme)(FilterContents);
export {
  FilterContents_default as default
};
