import React from "react";
import _ from "lodash/fp.js";
import F from "futil";
import { observer } from "mobx-react";
import styles from "../styles/index.js";
import OperatorMenu from "./OperatorMenu.js";
import { useFilterDropTarget } from "./DragDrop/FilterDropTarget.js";
let HorizontalLine = observer(({ node, child }) => {
  const marginLeft = `${(styles.operatorWidth - styles.lineWidth) / 2}px`;
  return /* @__PURE__ */ React.createElement(
    "div",
    {
      style: {
        width: child.children ? "100%" : `calc(100% - ${marginLeft})`,
        height: styles.operatorHeight / 2,
        marginLeft,
        borderBottom: `solid ${styles.lineWidth}px black`,
        borderBottomColor: styles.joinColor(node.join)
      }
    }
  );
});
let VerticalLine = observer(({ node }) => /* @__PURE__ */ React.createElement(
  "div",
  {
    style: {
      flex: 1,
      marginLeft: `${(styles.operatorWidth - styles.lineWidth) / 2}px`,
      borderLeft: `solid ${styles.lineWidth}px black`,
      borderLeftColor: styles.joinColor(node.join)
    }
  }
));
let OperatorTag = observer(({ node, hover, theme }) => /* @__PURE__ */ React.createElement(
  theme.Button,
  {
    style: {
      width: `${styles.operatorWidth}px`,
      lineHeight: `${styles.operatorHeight}px`,
      ...styles.bgJoin(F.view(hover.join) || node),
      ...F.view(hover.join) && { fontStyle: "italic" },
      // Reset button styles
      padding: 0,
      ...styles.buttonStyleReset
    }
  },
  F.view(hover.join) || node.join
));
let Operator = ({ hover, node, child, parent, tree, index, theme, adding }) => {
  const isLast = index === _.size(_.toArray(node.children)) - 1;
  const [{ canDrop }, drop] = useFilterDropTarget({
    drop(source) {
      tree.move(source.node.path, {
        path: node.path,
        index: index + 1
      });
    }
  });
  return /* @__PURE__ */ React.createElement(
    "div",
    {
      ref: drop,
      style: {
        position: "relative",
        display: "flex",
        flexDirection: "column",
        width: `${styles.operatorWidth + styles.ruleGutter}px`,
        ...canDrop && styles.bgPreview(node)
      }
    },
    (index !== 0 || node.join === "not") && /* @__PURE__ */ React.createElement("div", { style: { position: "absolute" } }, /* @__PURE__ */ React.createElement(
      theme.Popover,
      {
        trigger: /* @__PURE__ */ React.createElement(OperatorTag, { ...{ node, hover, theme, canDrop } }),
        style: {
          // Add top spacing between popover and trigger
          marginTop: "10px",
          padding: styles.boxPadding
        }
      },
      /* @__PURE__ */ React.createElement(OperatorMenu, { ...{ node, hover, tree, parent, child, theme } })
    )),
    /* @__PURE__ */ React.createElement(HorizontalLine, { ...{ node, child } }),
    (!isLast || F.view(adding)) && /* @__PURE__ */ React.createElement(VerticalLine, { node })
  );
};
var Operator_default = observer(Operator);
export {
  Operator_default as default
};
