import React, { useState } from "react";
import _ from "lodash/fp.js";
import F from "futil";
import { withTheme } from "../utils/theme.js";
import { toNumber } from "../utils/format.js";
import { setDisplayName } from "react-recompose";
import { observer } from "mobx-react";
import { Flex } from "../greyVest/index.js";
import { contexturifyWithoutLoader } from "../utils/hoc.js";
let commonStyle = {
  justifyContent: "space-between",
  alignItems: "center",
  display: "flex",
  cursor: "pointer"
};
let displayFn = (name, label) => _.isString(label) ? label : name;
let displayBlankFn = () => /* @__PURE__ */ React.createElement("i", null, "Not Specified");
let Cardinality = _.flow(
  setDisplayName("Cardinality"),
  observer
)(({ node, tree }) => {
  let size = node.size || 10;
  let count = _.get("context.cardinality", node);
  if (count) {
    return /* @__PURE__ */ React.createElement(
      Flex,
      {
        className: "contexture-facet-cardinality",
        justifyContent: "space-between"
      },
      /* @__PURE__ */ React.createElement("div", null, "Showing ", toNumber(_.min([size, _.size(node.context.options)])), " of", " ", toNumber(count)),
      count > size && /* @__PURE__ */ React.createElement("div", null, /* @__PURE__ */ React.createElement(
        "a",
        {
          onClick: () => tree.mutate(node.path, { size: size + 10 }),
          style: { cursor: "pointer" }
        },
        "View More"
      ))
    );
  }
  return null;
});
let SelectAll = _.flow(
  setDisplayName("SelectAll"),
  observer,
  withTheme
)(({ node, tree, theme: { Checkbox }, maxChecked = 500 }) => {
  let notChecked = _.difference(
    _.map("name", _.get("context.options", node)),
    node.values
  );
  let isAllChecked = _.isEmpty(notChecked);
  let allChecked = [...node.values, ...notChecked];
  let isOverTheLimit = _.size(allChecked) > maxChecked;
  return !isOverTheLimit || isAllChecked ? /* @__PURE__ */ React.createElement("label", { style: commonStyle }, /* @__PURE__ */ React.createElement(
    Checkbox,
    {
      checked: isAllChecked,
      onChange: () => {
        if (isAllChecked)
          tree.mutate(node.path, {
            values: []
          });
        else {
          tree.mutate(node.path, { values: allChecked });
        }
      }
    }
  ), /* @__PURE__ */ React.createElement("div", { style: { flex: 2, padding: "0 5px" } }, "Select All Visible")) : null;
});
let FacetOptionsFilter = _.flow(
  setDisplayName("FacetOptionsFilter"),
  observer,
  withTheme
)(({ tree, node, theme: { TextInput, Button, ButtonGroup } }) => {
  let [val, setVal] = useState(node.optionsFilter);
  let buttonEnabled = val !== node.optionsFilter;
  let submit = () => buttonEnabled && tree.mutate(node.path, { optionsFilter: val });
  return /* @__PURE__ */ React.createElement(ButtonGroup, null, /* @__PURE__ */ React.createElement(
    TextInput,
    {
      value: val,
      onChange: (e) => {
        setVal(e.target.value);
      },
      onKeyPress: (e) => e.key === "Enter" && submit(),
      onBlur: submit,
      placeholder: "Search..."
    }
  ), /* @__PURE__ */ React.createElement(Button, { primary: node.optionsFilter !== val, onClick: submit }, "Find"));
});
let FacetCheckboxList = contexturifyWithoutLoader(
  ({
    tree,
    node,
    hide,
    display = displayFn,
    displayBlank = displayBlankFn,
    formatCount,
    theme: { Checkbox }
  }) => _.flow(
    _.partition((x) => _.includes(x.name, node.values)),
    _.flatten,
    F.mapIndexed(({ name, label, count }, i) => {
      let lens = tree.lens(node.path, "values");
      const displayName = display(name, label);
      return /* @__PURE__ */ React.createElement(
        "label",
        {
          key: i,
          style: commonStyle,
          title: `${typeof displayName === "string" ? displayName : name} : ${formatCount(count)}`
        },
        /* @__PURE__ */ React.createElement(Checkbox, { ...F.domLens.checkboxValues(name, lens) }),
        /* @__PURE__ */ React.createElement("div", { style: { flex: 2, padding: "0 5px" } }, displayName || displayBlank()),
        !hide.counts && /* @__PURE__ */ React.createElement("div", null, formatCount(count))
      );
    })
  )(_.get("context.options", node))
);
export {
  Cardinality,
  FacetCheckboxList,
  FacetOptionsFilter,
  SelectAll,
  displayBlankFn,
  displayFn
};
