import _ from "lodash/fp.js";
import React from "react";
let toNumber = (number, ...params) => {
  if (_.isNumber(number)) {
    let formatter = Intl.NumberFormat(params);
    return formatter.format(number);
  }
  return NaN;
};
let addBlankRows = (rows, pageSize, key) => {
  if (rows.length === 0)
    return rows;
  let blankRows = [...Array(pageSize - rows.length)].map((_2, i) => ({
    ...rows[i % rows.length],
    // unique deterministic IDs
    [key]: `${rows[i % rows.length][key]}${i}`,
    isBlank: true
  }));
  return [...rows, ...blankRows];
};
let blank = _.memoize(_.replace(/[^ |]/gi, "\u2588"));
let toBlankText = (display, data, record, props) => {
  let rendered = display(data, record, props);
  if (typeof rendered === "object") {
    try {
      return display(blank(data), record, props);
    } catch {
      return blank(_.toString(data).slice(40));
    }
  } else {
    return blank(rendered);
  }
};
let blankResult = (display) => (data, record, props) => /* @__PURE__ */ React.createElement(
  "span",
  {
    style: {
      fontFamily: "monospace",
      display: "inline-block",
      opacity: 0.2
    }
  },
  toBlankText(display, data, record, props)
);
export {
  addBlankRows,
  blankResult,
  toNumber
};
