import React from "react";
import { observer } from "mobx-react";
import _ from "lodash/fp.js";
import { StripedLoader } from "../greyVest/index.js";
import { wrapDisplayName } from "./react.js";
import { withTheme } from "./theme.js";
let withNode = (Component) => wrapDisplayName(
  "withNode",
  Component
)((props) => {
  let { tree, node, path } = props;
  node = node || tree && path && tree.getNode(path);
  if (!node)
    throw Error(`Node not provided, and couldn't find node at ${path}`);
  return /* @__PURE__ */ React.createElement(Component, { ...props, node });
});
let withLoader = (Component) => _.flow(
  wrapDisplayName("withLoader", Component),
  observer
)(({ Loader, ...props }) => {
  let { theme = {}, node } = props;
  Loader = Loader || theme.Loader || StripedLoader;
  return /* @__PURE__ */ React.createElement(Loader, { loading: node && node.updating }, /* @__PURE__ */ React.createElement(Component, { node, ...props }));
});
let contexturify = _.flow(observer, withLoader, withNode, withTheme);
let contexturifyWithoutLoader = _.flow(observer, withNode, withTheme);
let withTreeLens = (Component) => wrapDisplayName(
  "withTreeLens",
  Component
)(({ prop = "value", ...props }) => /* @__PURE__ */ React.createElement(
  Component,
  {
    ...{ lens: props.tree.lens(props.node.path, prop), ...props }
  }
));
export {
  contexturify,
  contexturifyWithoutLoader,
  withLoader,
  withNode,
  withTreeLens
};
