import _ from "lodash/fp.js";
import F from "futil";
import { flattenPlainObject } from "./futil.js";
let applyDefaults = F.mapValuesIndexed((val, field) => ({
  field,
  label: F.autoLabel(field),
  order: 0,
  // `_.get('push') is used instead of `_.isArray` to match mobx4 arrays
  display: (x) => F.when(_.get("push"), _.join(", "))(x),
  ...val
}));
let getRecord = F.when("_source", (x) => ({
  _id: x._id,
  _highlight: x.highlight,
  ...x._source
}));
let getResults = F.cascade([
  "context.response.results",
  "context.results"
]);
let inferSchema = _.flow(
  getResults,
  _.head,
  getRecord,
  flattenPlainObject
);
let defaultNodeProps = (field, fields, type) => _.get([field, "defaultNodeProps", type], fields);
let schemaFieldProps = _.curry(
  (props, { field }, fields) => _.pick(props, fields[field])
);
let componentForType = (TypeMap) => ({ type }) => F.whenExists(F.singleObject("component"))(TypeMap[type]);
let fieldsFromSchema = _.curry(
  (schemas, search) => schemas[search.tree.schema].fields
);
export {
  applyDefaults,
  componentForType,
  defaultNodeProps,
  fieldsFromSchema,
  getRecord,
  getResults,
  inferSchema,
  schemaFieldProps
};
