import F from "futil";
import _ from "lodash/fp.js";
import { defaultNodeProps } from "./schema.js";
let oppositeJoin = (node) => F.getOrReturn("join", node) === "and" ? "or" : "and";
let randomString = () => Math.random().toString(36).substring(7);
let blankNode = () => ({ key: randomString() });
let newNodeFromType = _.curry((type, fields, node) => ({
  type,
  ..._.pick(["key", "field"], node),
  ...defaultNodeProps(node.field, fields, type)
}));
let newNodeFromField = ({ field, fields, ...optionalNodeProps }) => {
  let type = _.get([field, "typeDefault"], fields);
  return {
    type,
    field,
    ...defaultNodeProps(field, fields, type),
    ...optionalNodeProps
  };
};
let transformNodeFromField = (args) => (node) => ({
  ..._.pick("key", node),
  ...newNodeFromField(args)
});
let indent = (Tree, parent, node, skipDefaultNode) => {
  let join = (parent || node).join;
  let path = _.toArray(node.path);
  let wrapperNode = {
    key: `${node.key}-${join}-group`,
    join: oppositeJoin(join)
  };
  let wrapperPath = [..._.dropRight(1, path), wrapperNode.key];
  Tree.wrapInGroup(path, wrapperNode);
  if (!skipDefaultNode)
    Tree.add(wrapperPath, blankNode());
  return Tree.getNode(wrapperPath);
};
let getTypeLabel = (tree, type) => _.getOr(F.autoLabel(type), ["types", type, "label"], tree);
let getTypeLabelOptions = _.curry(
  (tree, types) => _.map((type) => ({ label: getTypeLabel(tree, type), value: type }), types)
);
export {
  blankNode,
  getTypeLabel,
  getTypeLabelOptions,
  indent,
  newNodeFromField,
  newNodeFromType,
  oppositeJoin,
  randomString,
  transformNodeFromField
};
